# FlakyBulkDto


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**value** | **bool** | Are autotests flaky | 
**autotest_ids** | **[str]** | Collection of identifiers of autotests which will be marked as stable/flaky | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


